==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ApplicationGatewaySkuArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ApplicationGatewaySkuArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.ApplicationGatewaySkuName
import com.pulumi.azurenative.network.kotlin.enums.ApplicationGatewayTier
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * SKU of an application gateway.
 * @property capacity Capacity (instance count) of an application gateway.
 * @property name Name of an application gateway SKU.
 * @property tier Tier of an application gateway.
 */
public data class ApplicationGatewaySkuArgs(
    public val capacity: Output<Int>? = null,
    public val name: Output<Either<String, ApplicationGatewaySkuName>>? = null,
    public val tier: Output<Either<String, ApplicationGatewayTier>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.ApplicationGatewaySkuArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.ApplicationGatewaySkuArgs =
        com.pulumi.azurenative.network.inputs.ApplicationGatewaySkuArgs.builder()
            .capacity(capacity?.applyValue({ args0 -> args0 }))
            .name(
                name?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .tier(
                tier?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ApplicationGatewaySkuArgs].
 */
@PulumiTagMarker
public class ApplicationGatewaySkuArgsBuilder internal constructor() {
    private var capacity: Output<Int>? = null

    private var name: Output<Either<String, ApplicationGatewaySkuName>>? = null

    private var tier: Output<Either<String, ApplicationGatewayTier>>? = null

    /**
     * @param value Capacity (instance count) of an application gateway.
     */
    @JvmName("qvaugodnbqeojekf")
    public suspend fun capacity(`value`: Output<Int>) {
        this.capacity = value
    }

    /**
     * @param value Name of an application gateway SKU.
     */
    @JvmName("fbrxixwniveceptw")
    public suspend fun name(`value`: Output<Either<String, ApplicationGatewaySkuName>>) {
        this.name = value
    }

    /**
     * @param value Tier of an application gateway.
     */
    @JvmName("eljtloshublrwvcf")
    public suspend fun tier(`value`: Output<Either<String, ApplicationGatewayTier>>) {
        this.tier = value
    }

    /**
     * @param value Capacity (instance count) of an application gateway.
     */
    @JvmName("ndypdukqqyrnvthd")
    public suspend fun capacity(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.capacity = mapped
    }

    /**
     * @param value Name of an application gateway SKU.
     */
    @JvmName("rvkfaftvikeokwyy")
    public suspend fun name(`value`: Either<String, ApplicationGatewaySkuName>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Name of an application gateway SKU.
     */
    @JvmName("yieasolalkjaytin")
    public fun name(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ApplicationGatewaySkuName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Name of an application gateway SKU.
     */
    @JvmName("xtkcdiunqnpbytwd")
    public fun name(`value`: ApplicationGatewaySkuName) {
        val toBeMapped = Either.ofRight<String, ApplicationGatewaySkuName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Tier of an application gateway.
     */
    @JvmName("nvugfbyacwjlwlen")
    public suspend fun tier(`value`: Either<String, ApplicationGatewayTier>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    /**
     * @param value Tier of an application gateway.
     */
    @JvmName("tfpumvptcfqaqmgl")
    public fun tier(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ApplicationGatewayTier>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    /**
     * @param value Tier of an application gateway.
     */
    @JvmName("bblfsgrombuvmhai")
    public fun tier(`value`: ApplicationGatewayTier) {
        val toBeMapped = Either.ofRight<String, ApplicationGatewayTier>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    internal fun build(): ApplicationGatewaySkuArgs = ApplicationGatewaySkuArgs(
        capacity = capacity,
        name = name,
        tier = tier,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ApplicationGatewaySkuArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ApplicationGatewaySkuArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.ApplicationGatewaySkuName
import com.pulumi.azurenative.network.kotlin.enums.ApplicationGatewayTier
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * SKU of an application gateway.
 * @property capacity Capacity (instance count) of an application gateway.
 * @property name Name of an application gateway SKU.
 * @property tier Tier of an application gateway.
 */
public data class ApplicationGatewaySkuArgs(
    public val capacity: Output<Int>? = null,
    public val name: Output<Either<String, ApplicationGatewaySkuName>>? = null,
    public val tier: Output<Either<String, ApplicationGatewayTier>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.ApplicationGatewaySkuArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.ApplicationGatewaySkuArgs =
        com.pulumi.azurenative.network.inputs.ApplicationGatewaySkuArgs.builder()
            .capacity(capacity?.applyValue({ args0 -> args0 }))
            .name(
                name?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .tier(
                tier?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ApplicationGatewaySkuArgs].
 */
@PulumiTagMarker
public class ApplicationGatewaySkuArgsBuilder internal constructor() {
    private var capacity: Output<Int>? = null

    private var name: Output<Either<String, ApplicationGatewaySkuName>>? = null

    private var tier: Output<Either<String, ApplicationGatewayTier>>? = null

    /**
     * @param value Capacity (instance count) of an application gateway.
     */
    @JvmName("aqcpnhnmommurutk")
    public suspend fun capacity(`value`: Output<Int>) {
        this.capacity = value
    }

    /**
     * @param value Name of an application gateway SKU.
     */
    @JvmName("uikggeglsndbvvld")
    public suspend fun name(`value`: Output<Either<String, ApplicationGatewaySkuName>>) {
        this.name = value
    }

    /**
     * @param value Tier of an application gateway.
     */
    @JvmName("xakmwujqbbogmcyt")
    public suspend fun tier(`value`: Output<Either<String, ApplicationGatewayTier>>) {
        this.tier = value
    }

    /**
     * @param value Capacity (instance count) of an application gateway.
     */
    @JvmName("pppnbmmcbdnjclir")
    public suspend fun capacity(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.capacity = mapped
    }

    /**
     * @param value Name of an application gateway SKU.
     */
    @JvmName("wsqpqqcwtlptdlae")
    public suspend fun name(`value`: Either<String, ApplicationGatewaySkuName>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Name of an application gateway SKU.
     */
    @JvmName("ccfbqafakjdplvnd")
    public fun name(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ApplicationGatewaySkuName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Name of an application gateway SKU.
     */
    @JvmName("uyfbwhlnrngigdfs")
    public fun name(`value`: ApplicationGatewaySkuName) {
        val toBeMapped = Either.ofRight<String, ApplicationGatewaySkuName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Tier of an application gateway.
     */
    @JvmName("scfsfmoadhcyhnmh")
    public suspend fun tier(`value`: Either<String, ApplicationGatewayTier>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    /**
     * @param value Tier of an application gateway.
     */
    @JvmName("chybknvhncvmmsgr")
    public fun tier(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ApplicationGatewayTier>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    /**
     * @param value Tier of an application gateway.
     */
    @JvmName("qfffqnmtafjbnvcy")
    public fun tier(`value`: ApplicationGatewayTier) {
        val toBeMapped = Either.ofRight<String, ApplicationGatewayTier>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    internal fun build(): ApplicationGatewaySkuArgs = ApplicationGatewaySkuArgs(
        capacity = capacity,
        name = name,
        tier = tier,
    )
}
